==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/class/System.Web/System.Web.UI.WebControls.WebParts/Part.cs <==
//
// System.Web.UI.WebControls.WebParts.Part
//
// Authors: Chris Toshok <toshok@novell.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0
using System;

namespace System.Web.UI.WebControls.WebParts
{

	public abstract class Part: Panel, INamingContainer, ICompositeControlDesignerAccessor
	{
		string description;
		string title;
		PartChromeState chrome_state;
		PartChromeType chrome_type;

		internal Part ()
		{
			description = "";
			title = "";
			chrome_state = PartChromeState.Normal;
			chrome_type = PartChromeType.Default;
		}

		[MonoTODO]
		public override void DataBind()
		{
			throw new NotImplementedException ();
		}

		[MonoTODO("not sure exactly what this one does..")]
		void ICompositeControlDesignerAccessor.RecreateChildControls ()
		{
			/* for now just call CreateChildControls to force
			 * the recreation of our children. */
			CreateChildControls ();
		}

		public virtual PartChromeState ChromeState
		{
			get {
				return chrome_state;
			}
			set {
				chrome_state = value;
			}
		}

		public virtual PartChromeType ChromeType
		{
			get {
				return chrome_type;
			}
			set {
				chrome_type = value;
			}
		}

		[MonoTODO]
		public virtual new ControlCollection Controls
		{
			get {
				throw new NotImplementedException ();
			}
		}

		public virtual string Description
		{
			get {
				return description;
			}
			set {
				description = value;
			}
		}

		public virtual string Title
		{
			get {
				return title;
			}
			set {
				title = value;
			}
		}

	}
}

#endif

==> mono_1.1.17.1.orig.tar.gz: mono-1.1.17.1/mcs/class/System.Web/System.Web.UI.WebControls.WebParts/Part.cs <==
//
// System.Web.UI.WebControls.WebParts.Part
//
// Authors: Chris Toshok <toshok@novell.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0
using System;

namespace System.Web.UI.WebControls.WebParts
{

	public abstract class Part: Panel, INamingContainer, ICompositeControlDesignerAccessor
	{
		string description;
		string title;
		PartChromeState chrome_state;
		PartChromeType chrome_type;
		ControlCollection controls;

		internal Part ()
		{
			description = "";
			title = "";
			chrome_state = PartChromeState.Normal;
			chrome_type = PartChromeType.Default;
		}

		[MonoTODO]
		public override void DataBind()
		{
			throw new NotImplementedException ();
		}

		[MonoTODO("not sure exactly what this one does..")]
		void ICompositeControlDesignerAccessor.RecreateChildControls ()
		{
			/* for now just call CreateChildControls to force
			 * the recreation of our children. */
			CreateChildControls ();
		}

		public virtual PartChromeState ChromeState
		{
			get {
				return chrome_state;
			}
			set {
				chrome_state = value;
			}
		}

		public virtual PartChromeType ChromeType
		{
			get {
				return chrome_type;
			}
			set {
				chrome_type = value;
			}
		}

		[MonoTODO]
		public virtual new ControlCollection Controls
		{
			get {
				if(controls == null)
					controls = new ControlCollection(this);
				return controls;
			}
		}

		public virtual string Description
		{
			get {
				return description;
			}
			set {
				description = value;
			}
		}

		public virtual string Title
		{
			get {
				return title;
			}
			set {
				title = value;
			}
		}
	}
}
#endif
